# streamlit-custom-component

Streamlit component that allows you to do X

## Installation instructions

```sh
pip install streamlit_interactive_gantt_job_shop
```

## Usage instructions

```python
import streamlit as st

from streamlit_interactive_gantt_job_shop import gantt_component

value = gantt_component()

st.write(value)
```
